@@ -29,6 +29,7 @@
 
 #include <assert.h>
 #include <errno.h>
+#include <libgen.h>
 #include <libratbag.h>
 #include <libudev.h>
 #include <stdio.h>
@@ -547,6 +548,13 @@ static bool install_ratbagd_devel_dbus_policy(void)
 		log_error("Failed to source policy file: %m\n");
 		goto out;
 	}
+
+	if (mkdir_p(dirname(strdupa(DBUS_POLICY_DST)), 0755)) {
+		log_error("Failed to create destination path: %m\n");
+		goto out;
+	}
+
+
 	out = open(DBUS_POLICY_DST, O_CREAT|O_WRONLY, 0644);
 	if (out == -1) {
 		log_error("Failed to open destination: %m\n");
