@@ -23,6 +23,7 @@
 
 #pragma once
 
+#include "config.h"
 #include <linux/input.h>
 #include <stdint.h>
 #include <stdbool.h>
@@ -594,6 +595,8 @@ extern struct ratbag_driver logitech_g600_driver;
 extern struct ratbag_driver roccat_driver;
 extern struct ratbag_driver gskill_driver;
 extern struct ratbag_driver steelseries_driver;
+extern struct ratbag_driver sinowealth_driver;
+extern struct ratbag_driver sinowealth_nubwo_driver;
 
 struct ratbag_device*
 ratbag_device_new(struct ratbag *ratbag, struct udev_device *udev_device,
