@@ -602,6 +602,8 @@ ratbag_create_context(const struct ratbag_interface *interface,
 	ratbag_register_driver(ratbag, &roccat_driver);
 	ratbag_register_driver(ratbag, &gskill_driver);
 	ratbag_register_driver(ratbag, &steelseries_driver);
+	ratbag_register_driver(ratbag, &sinowealth_driver);
+	ratbag_register_driver(ratbag, &sinowealth_nubwo_driver);
 
 	return ratbag;
 }
